@@ -8,10 +8,10 @@ module Fog
 
         def end_element(name)
           case name
-            when 'Href', 'Name'
-              @response[name.downcase] = value
-            when 'Id'
-              @response['id'] = value.to_i
+          when "Href", "Name"
+            @response[name.downcase] = value
+          when "Id"
+            @response["id"] = value.to_i
           end
         end
       end
